==> okteta-0.25.2.tar.xz: okteta-0.25.2/kasten/gui/io/streamencoder/base32/bytearraybase32streamencoderconfigeditorfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYBASE32STREAMENCODERCONFIGEDITORFACTORY_H
#define BYTEARRAYBASE32STREAMENCODERCONFIGEDITORFACTORY_H

// lib
#include <kasten/okteta/oktetakastengui_export.h>
// Kasten gui
#include <kasten/abstractmodelstreamencoderconfigeditorfactory.h>

namespace Kasten {

class ByteArrayBase32StreamEncoderConfigEditorFactory : public AbstractModelStreamEncoderConfigEditorFactory
{
public:
    ByteArrayBase32StreamEncoderConfigEditorFactory();
    ~ByteArrayBase32StreamEncoderConfigEditorFactory() override;

public:
    AbstractModelStreamEncoderConfigEditor* tryCreateConfigEditor(AbstractModelStreamEncoder* encoder) const override;
};

}

#endif

==> okteta_15.12.3.orig.tar.xz: okteta-15.12.3/kasten/gui/io/streamencoder/base32/bytearraybase32streamencoderconfigeditorfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYBASE32STREAMENCODERCONFIGEDITORFACTORY_H
#define BYTEARRAYBASE32STREAMENCODERCONFIGEDITORFACTORY_H

// lib
#include <kasten/okteta/oktetakastengui_export.h>
// Kasten gui
#include <kasten/abstractmodelstreamencoderconfigeditorfactory.h>


namespace Kasten
{

class ByteArrayBase32StreamEncoderConfigEditorFactory : public AbstractModelStreamEncoderConfigEditorFactory
{
  public:
    ByteArrayBase32StreamEncoderConfigEditorFactory();
    virtual ~ByteArrayBase32StreamEncoderConfigEditorFactory();

  public:
    virtual AbstractModelStreamEncoderConfigEditor* tryCreateConfigEditor( AbstractModelStreamEncoder* encoder ) const;
};

}

#endif
